@@ -13,11 +13,8 @@ def execute(helper, config, args):
     Rebuilds an environment
     """
     env_config = parse_env_config(config, args.environment)
-    cname_prefix = env_config.get('cname_prefix', None)
-    real_env_name = helper.environment_name_for_cname(cname_prefix)
-
-    helper.rebuild_environment(real_env_name)
+    helper.rebuild_environment(args.environment)
 
     # wait
     if not args.dont_wait:
-        helper.wait_for_environments(real_env_name, health='Green', status='Ready')
\ No newline at end of file
+        helper.wait_for_environments(args.environment, health='Green', status='Ready')
\ No newline at end of file
